#
# spec file for package python-pydyf
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2022-2023 Dr. Axel Braun <DocB@openSUSE.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pydyf
Version:        0.11.0
Release:        1.3
Summary:        A low-level PDF generator
License:        BSD-3-Clause
URL:            https://www.courtbouillon.org/pydyf
Source:         https://files.pythonhosted.org/packages/source/p/pydyf/pydyf-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION Testing
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  gs
# /SECTION
%python_subpackages

%description
A low-level PDF generator written in Python and based on PDF specification 1.7.

%prep
%setup -q -n pydyf-%{version}
sed -i 's:--isort --flake8::' pyproject.toml
chmod -x pydyf/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pydyf
%{python_sitelib}/pydyf-%{version}*-info

%changelog
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.0:
  * Remove deprecated version and identifier parameters
  * Change some function names for consistency
  * Allow extra operands for special colors
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * Add standard compliant default identifier
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.0:
  * Python 3.12 is supported and tested
  * Python 3.8+ is now needed, Python 3.7 is not supported
    anymore
* Thu Jan 11 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add %%{?sle15_python_module_pythons} macro
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Add text rise operator
* Sun Jul 16 2023 Axel Braun <axel.braun@gmx.de>
- version 0.7.0
  * Python 3.11 is supported and tested
  * Fix size of fields for xref
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * Add an option to use compressed object streams for PDF 1.5+,
    with financial support from Code & Co.
  * Add new text operators
  * Clean and fix documentation
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.5.0
  * Add the PDF.page_references property
  * Revert the PDF.pages['Kids'] behavior to be backwards compatible with version 0.3.0
- Update to version 0.4.0
  * Allow nth page’s reference to be retrieved using PDF.pages['Kids'][n]
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.3.0
  * Support marked content
  * Allow version and ID to be specified when initializing PDF objects
* Tue Aug 16 2022 Ben Greiner <code@bnavigator.de>
- Implement python packaging best practices for build requirements,
  testing and files section
* Sat Aug 13 2022 Axel Braun <axel.braun@gmx.de>
- Update to version 0.2.0
  * Requires Python 3.7+
  * change buildsystem to .toml
* Wed Dec 15 2021 pgajdos@suse.com
- fix build (testsuite run)
- pytest-runner is not required for build
* Thu Nov 18 2021 Axel Braun <axel.braun@gmx.de>
- version 0.1.2
  inital OBS build
